@@ -994,6 +994,8 @@ class Node(metaclass=NodeMeta):
         Looks up the siteconf in ENRICH_ETC and
         returns appropriate entry
 
+        This name should in specific in the credentials 
+        section of siteconf.
         """
         if not hasattr(self.config, 'siteconf'):
             raise Exception("No siteconf")
@@ -1080,6 +1082,13 @@ class Node(metaclass=NodeMeta):
         File path resolver. Insert transform and pass to the pipeline
         execution engine.
 
+        Args:
+           abspath (bool): Generate absolute path (default: True)
+           extra (dict): Extra args for resolving the path
+
+        Returns:
+           path (str): Resolved path
+
         """
 
         extra = kwargs.pop('extra', {})
