@@ -590,20 +590,61 @@ class RunManagerBase(object):
         self.runcls = RunBase
         self.numruns = kwargs.get('numruns', 100)
 
-    def load(self, offset=0, page=50):
+    def load_one_run(self, outputdirs, runid):
+
+        # Check if already present. If so, nothing to be done
+        run = self.get_run(runid)
+        if run is not None:
+            return
+
+        logger.debug("RunID ({})missing in cache. Loading".format(runid),
+                     extra={
+                         'transform': self.config.name
+                     })
+        rundir = None
+        for outputdir in outputdirs:
+            if runid in os.listdir(outputdir):
+                rundir = os.path.join(outputdir, runid)
+                break
+
+        # Nothing to be done...
+        if rundir is None:
+            logger.error("RunID ({}) could not be found".format(runid),
+                         extra={
+                             'transform': self.config.name,
+                             'data': 'Output dirs = {}'.format(", ".join(outputdirs))
+                         })
+            return
+
+        try:
+            run = self.runcls(config=self.config,
+                              name=runid,
+                              rundir=rundir)
+            run.load()
+            self.runs.append(run)
+            logger.exception("Loaded a new run: {}".format(runid),
+                             extra={
+                                 'transform': self.config.name,
+                             })
+        except:
+            logger.exception("Unable to load runid: {}".format(runid),
+                             extra={
+                                 'transform': self.config.name,
+                             })
+        return
+
+    def load(self, offset=0, page=50, runid=None):
         """
         Load the runs
 
         Args:
 
-             full (bool): Load all runs (default: False)
+             offset: offset from the last run
+             page: number of runs per page
+             runid: arbitrary runid (overrides the offset and page
 
         """
 
-        extra = 10
-        run_cache = { r.runid : r for r in self.runs }
-        self.runs = []
-
         # Default
         outputdirs = [self.config.outputdir]
 
@@ -617,6 +658,13 @@ class RunManagerBase(object):
             if os.path.exists(mountdir):
                 outputdirs.append(mountdir)
 
+        if runid is not None:
+            return self.load_one_run(outputdirs, runid)
+
+        extra = 10
+        run_cache = { r.runid : r for r in self.runs }
+        self.runs = []
+
         runids = []
         count = 0
         for outputdir in outputdirs:
@@ -625,7 +673,8 @@ class RunManagerBase(object):
             if not os.path.exists(outputdir):
                 continue
 
-            # If we have not seen the outputdir, then include it.
+            # Default path where no run id is specified. If we have
+            # not seen the outputdir, then include it.
             for runid in sorted(os.listdir(outputdir), reverse=True):
                 if runid not in runids:
                     runids.append({
@@ -638,7 +687,6 @@ class RunManagerBase(object):
                 if count > offset + page + extra:
                     break
 
-
         errors = []
         for r in runids:
             if self.config.runid == r['runid']:
@@ -651,10 +699,12 @@ class RunManagerBase(object):
 
             # Get timestamp of the file.
             logfile = os.path.join(rundir, 'log.json')
+            if not os.path.exists(logfile):
+                continue
+
             try:
                 mtime = os.path.getmtime(logfile)
             except:
-                traceback.print_exc()
                 mtime = 0
 
             last_modified_date = datetime.fromtimestamp(mtime)
@@ -707,6 +757,7 @@ class RunManagerBase(object):
         for r in self.runs:
             if r.runid == runid:
                 return r
+
         return None
 
     def get_last_run(self, status="success"):
