@@ -19,7 +19,7 @@ def greenbg(txt):
     return "{} \u2713 {} {}".format(bg('light_green'), txt, attr(0))
 
 def redbg(txt):
-    return "{} \u274C {} {}".format(bg('light_red'), txt, attr(0))
+    return "{} \u274C {} {}".format(bg('indian_red_1a'), txt, attr(0))
 
 def orangebg(txt):
     return "{} \u0023 {} {}".format(bg('dark_orange_3a'), txt, attr(0))
