@@ -1919,7 +1919,7 @@ def test_transform(pkgdir, capture=False, context=None):
     }
 
     tests = [
-        test_structure,
+        #test_structure,
         # test_pytest,
         test_loading,
         test_instantiation,
@@ -1983,7 +1983,7 @@ def load_transform(pkgdir, capture, context):
     }
 
     tests = [
-        test_structure,
+        #test_structure,
         # test_pytest,
         test_loading,
         test_instantiation,
